#! /bin/bash
#
# Copyright 2008 Matteo Collina <matteo.collina@gmail.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of version 2 of the GNU General Public License as
# published by the Free Software Foundation.

export DISPLAY=:0.0

TMPFILE=/tmp/.launcher/resume-event

case "$1" in 
	suspend|hibernate)
		rm -rf $TMPFILE
    echo "Removed resume-notify file"

	;;
	resume|thaw)
 	  touch $TMPFILE
    echo "Created resume-notify file"
	;;
esac
